import request from "@/utils/request.js";

//获取首页数据 无需授权
export function getIndexData()
{
	return request.get("index/getIndex",{},{ noAuth : true});
}

//站点信息
export function siteResouce()
{
	return request.get("pub/siteResouce",{},{ noAuth : true});
}

//公告列表
export function getNotice()
{
	return request.post("index/newsList",{},{ noAuth : true});
}

//公告详情
export function newsDetail(data)
{
	return request.post("index/news",data,{ noAuth : true});
}

//仓库列表
export function getWarehouse()
{
	return request.get("pub/warehouse",{},{ noAuth : true});
}

//产品列表
export function productList(data)
{
	return request.post("index/proList",data,{ noAuth : true});
}

//产品详情
export function productDetail(data)
{
	return request.post("index/proItem",data,{ noAuth : true});
}

//推荐产品
export function recommend()
{
	return request.post("index/proRand",{},{ noAuth : true});
}

//获取验证码
export function registerVerify(data)
{
	return request.post("login/yzm",data,{ noAuth : true});
}

//注册一
export function ApiReg1(data)
{
	return request.post("login/reg1",data,{ noAuth : true});
}

//注册二
export function ApiReg2(data)
{
	return request.post("login/reg2",data,{ noAuth : true});
}

//登录
export function loginApi(data)
{
	return request.post("login/l",data,{ noAuth : true});
}

//重置密码验证码
export function ApiForgetYzm(data)
{
	return request.post("login/forgetYzm",data,{ noAuth : true});
}

//重置密码一
export function ApiForget1(data)
{
	return request.post("login/forget1",data,{ noAuth : true});
}

//重置密码一
export function ApiForget2(data)
{
	return request.post("login/forget2",data,{ noAuth : true});
}

//用户信息
export function getUserInfo()
{
	return request.get("user/init");
}

//订单统计
export function getOrder()
{
	return request.post("user/orderInit");
}

//订单列表
export function getOrderList(data)
{
	return request.post("user/getOrderList",data);
}

//订单详情
export function orderSubItem(data)
{
	return request.post("user/orderSubItem",data);
}

//邀请链接
export function spreadLink()
{
	return request.post("user/extension");
}

//平台列表
export function platformList()
{
	return request.post("platform/list");
}

//购买页仓库
export function ApiWarehouse()
{
	return request.get("user/warehouse");
}

//提交订单
export function submitOrder(data)
{
	return request.post("user/subOrder",data);
}

//支付订单
export function payOrder(data)
{
	return request.post("user/getPayOrder",data);
}

//余额支付
export function balancePay(data)
{
	return request.post("user/balancePay",data);
}

//微信支付
export function wxPay(data)
{
	return request.post("weixin/wxPay",data);
}

//取消订单
export function cancelOrder(data)
{
	return request.post("user/cancelOrder",data);
}

//充值金额列表
export function rechargeInit()
{
	return request.post("user/rechargeXinit");
}

//微信充值
export function wxRecharge(data)
{
	return request.post("user/wxRecharge",data);
}

//账单明细
export function recordList(data)
{
	return request.post("user/detailList",data);
}

//账户余额
export function account()
{
	return request.post("user/rechargeInit");
}